<?php
/**
 * Fotografie Pro Hero Content Options
 * @package Fotografie Pro
 */

/**
 * Add hero content options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function fotografie_hero_content_options( $wp_customize ) {
	$wp_customize->add_section( 'fotografie_hero_content_options', array(
		'title' => esc_html__( 'Hero Content Options', 'fotografie-pro' ),
		'panel' => 'fotografie_theme_options',
	) );

	$wp_customize->add_setting( 'fotografie_hero_content_visibility', array(
		'default'           => 'homepage',
		'sanitize_callback' => 'fotografie_sanitize_select',
	) );

	$wp_customize->add_control( 'fotografie_hero_content_visibility', array(
		'choices'  => fotografie_section_visibility_options(),
		'label'    => esc_html__( 'Enable on', 'fotografie-pro' ),
		'section'  => 'fotografie_hero_content_options',
		'type'     => 'select',
	) );

	$wp_customize->add_setting( 'fotografie_hero_content_type', array(
		'default'           => 'page',
		'sanitize_callback' => 'fotografie_sanitize_select',
	) );

	$types = fotografie_section_type_options();

	// Unset demo as hero content has no demo.
	unset( $types['demo'] );

	$wp_customize->add_control( 'fotografie_hero_content_type', array(
		'active_callback' => 'fotografie_is_hero_content_active',
		'choices'         => $types,
		'label'           => esc_html__( 'Type', 'fotografie-pro' ),
		'section'         => 'fotografie_hero_content_options',
		'type'            => 'select',
	) );

	$wp_customize->add_setting( 'fotografie_hero_content', array(
		'default'           => '0',
		'sanitize_callback' => 'fotografie_sanitize_post',
	) );

	$wp_customize->add_control( 'fotografie_hero_content', array(
		'active_callback' => 'fotografie_is_hero_page_content_active',
		'label'           => esc_html__( 'Page', 'fotografie-pro' ),
		'section'         => 'fotografie_hero_content_options',
		'type'            => 'dropdown-pages',
	) );

	$wp_customize->add_setting( 'fotografie_hero_content_post', array(
		'default'           => '0',
		'sanitize_callback' => 'fotografie_sanitize_post',
	) );

	$wp_customize->add_control( 'fotografie_hero_content_post', array(
		'active_callback' => 'fotografie_is_hero_post_content_active',
		'label'           => esc_html__( 'Post', 'fotografie-pro' ),
		'section'         => 'fotografie_hero_content_options',
		'choices'         => fotografie_posts_list(),
		'type'            => 'select',
	) );

	// create an empty array.
	$cats = array();

	$cats['0'] = esc_html__( '-- Select --', 'fotografie-pro' );

	// we loop over the categories and set the names and
	// labels we need.
	foreach ( get_categories() as $categories => $category ) {
		$cats[ $category->term_id ] = $category->name;
	}

	$wp_customize->add_setting( 'fotografie_hero_content_category', array(
		'default'           => '0',
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( 'fotografie_hero_content_category', array(
		'active_callback' => 'fotografie_is_hero_category_content_active',
		'label'           => esc_html__( 'Category', 'fotografie-pro' ),
		'type'            => 'select',
		'choices'         => $cats,
		'section'         => 'fotografie_hero_content_options',
	) );

	$wp_customize->add_setting( 'fotografie_disable_hero_content_title', array(
		'sanitize_callback' => 'fotografie_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'fotografie_disable_hero_content_title', array(
		'active_callback' => 'fotografie_is_hero_post_page_category_content_active',
		'label'           => esc_html__( 'Check to disable title', 'fotografie-pro' ),
		'section'         => 'fotografie_hero_content_options',
		'type'            => 'checkbox',
	) );

	$wp_customize->add_setting( 'fotografie_hero_content_title', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control(  'fotografie_hero_content_title', array(
		'active_callback' => 'fotografie_is_hero_custom_content_active',
		'label'           => esc_html__( 'Title', 'fotografie-pro' ),
		'section'         => 'fotografie_hero_content_options',
		'type'            => 'text',
	) );

	$wp_customize->add_setting( 'fotografie_hero_content_content', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'fotografie_hero_content_content', array(
		'active_callback' => 'fotografie_is_hero_custom_content_active',
		'label'           => esc_html__( 'Content', 'fotografie-pro' ),
		'section'         => 'fotografie_hero_content_options',
		'type'            => 'textarea',
	) );

	$wp_customize->add_setting( 'fotografie_hero_content_image', array(
		'sanitize_callback' => 'fotografie_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'fotografie_hero_content_image', array(
		'active_callback' => 'fotografie_is_hero_custom_content_active',
		'label'           => esc_html__( 'Image', 'fotografie-pro' ),
		'section'         => 'fotografie_hero_content_options',
	) ) );

	$wp_customize->add_setting( 'fotografie_hero_content_link', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control(  'fotografie_hero_content_link', array(
		'active_callback' => 'fotografie_is_hero_custom_content_active',
		'label'           => esc_html__( 'Image Link', 'fotografie-pro' ),
		'section'         => 'fotografie_hero_content_options',
	) );

	$wp_customize->add_setting( 'fotografie_hero_content_target', array(
		'sanitize_callback' => 'fotografie_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'fotografie_hero_content_target', array(
		'active_callback' => 'fotografie_is_hero_custom_content_active',
		'label'           => esc_html__( 'Check to Open Link in New Window/Tab', 'fotografie-pro' ),
		'section'         => 'fotografie_hero_content_options',
		'type'            => 'checkbox',
	) );

	$wp_customize->add_setting( 'fotografie_hero_content_more_text', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'fotografie_hero_content_more_text', array(
		'active_callback' => 'fotografie_is_hero_custom_content_active',
		'label'           => esc_html__( 'Button Text', 'fotografie-pro' ),
		'section'         => 'fotografie_hero_content_options',
	) );

	$wp_customize->add_setting( 'fotografie_hero_content_more_link', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control(  'fotografie_hero_content_more_link', array(
		'active_callback' => 'fotografie_is_hero_custom_content_active',
		'label'           => esc_html__( 'Button Link', 'fotografie-pro' ),
		'section'         => 'fotografie_hero_content_options',
	) );

	$wp_customize->add_setting( 'fotografie_hero_content_more_target', array(
		'sanitize_callback' => 'fotografie_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'fotografie_hero_content_more_target', array(
		'active_callback' => 'fotografie_is_hero_custom_content_active',
		'label'           => esc_html__( 'Check to Open Button Link in New Window/Tab', 'fotografie-pro' ),
		'section'         => 'fotografie_hero_content_options',
		'type'            => 'checkbox',
	) );
}
add_action( 'customize_register', 'fotografie_hero_content_options' );
