<?php
/**
 * Fotografie Pro Theme Options
 *
 * @package Fotografie Pro
 */

/**
 * Add theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function fotografie_theme_options( $wp_customize ) {
	$wp_customize->add_panel( 'fotografie_theme_options', array(
		'title'    => esc_html__( 'Theme Options', 'fotografie-pro' ),
		'priority' => 130,
	) );

	// Breadcrumb Option.
	$wp_customize->add_section( 'fotografie_breadcrumb_options', array(
		'description'   => esc_html__( 'Breadcrumbs are a great way of letting your visitors find out where they are on your site with just a glance. You can enable/disable them on homepage and entire site.', 'fotografie-pro' ),
		'panel'         => 'fotografie_theme_options',
		'title'         => esc_html__( 'Breadcrumb', 'fotografie-pro' ),
	) );

	$wp_customize->add_setting( 'fotografie_breadcrumb_option', array(
		'default'           => 1,
		'sanitize_callback' => 'fotografie_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'fotografie_breadcrumb_option', array(
		'label'    => esc_html__( 'Check to enable Breadcrumb', 'fotografie-pro' ),
		'section'  => 'fotografie_breadcrumb_options',
		'type'     => 'checkbox',
	) );

	// Font Family Options.
	$wp_customize->add_section( 'fotografie_font_family', array(
		'panel' => 'fotografie_theme_options',
		'title' => esc_html__( 'Font Family Options', 'fotografie-pro' ),
	) );

	$avaliable_fonts = fotografie_avaliable_fonts();

	$choices = array();

	foreach ( $avaliable_fonts as $font ) {
		$choices[ $font['value'] ] = str_replace( '"', '', $font['label'] );
	}

	$font_family_options = fotografie_font_family_options();

	foreach ( $font_family_options as $key => $value ) {
		$wp_customize->add_setting( $key, array(
			'default'           => $value['default'],
			'sanitize_callback' => 'fotografie_sanitize_select',
		) );

		$wp_customize->add_control( $key, array(
			'choices'  => $choices,
			'label'    => $value['label'],
			'section'  => 'fotografie_font_family',
			'type'     => 'select',
		) );
	}

	$wp_customize->add_setting( 'fotografie_reset_typography', array(
		'sanitize_callback' => 'fotografie_sanitize_checkbox',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( 'fotografie_reset_typography', array(
		'label'    => esc_html__( 'Check to reset fonts', 'fotografie-pro' ),
		'section'  => 'fotografie_font_family',
		'type'     => 'checkbox',
	) );

	// Footer Editor Options.
	$wp_customize->add_section( 'fotografie_footer_editor_options', array(
		'title'       => esc_html__( 'Footer Editor Options', 'fotografie-pro' ),
		'description' => esc_html__( 'You can either add html or plain text', 'fotografie-pro' ),
		'panel'       => 'fotografie_theme_options',
	) );

	$theme_data = wp_get_theme();

	$def_footer_text = sprintf( _x( 'Copyright &copy; %1$s %2$s. All Rights Reserved. %3$s', '1: Year, 2: Site Title with home URL, 3: Privacy Policy Link', 'fotografie-pro' ), '[the-year]', '[site-link]', '[privacy-policy-link]' ) . ' &#124; ' . $theme_data->get( 'Name' ) . '&nbsp;' . esc_html__( 'by', 'fotografie-pro' ) . '&nbsp;<a target="_blank" href="' . $theme_data->get( 'AuthorURI' ) . '">' . esc_html( $theme_data->get( 'Author' ) ) . '</a>';

	$wp_customize->add_setting( 'fotografie_footer_content', array(
		'default'           => $def_footer_text,
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'fotografie_footer_content', array(
		'description' => esc_html__( 'You can add custom shortcodes, which will be automatically inserted into your theme. Some shorcodes: [the-year], [site-link] and [privacy-policy-link] for current year, site link and privacy policy link respectively.', 'fotografie-pro' ),
		'label'       => esc_html__( 'Footer content', 'fotografie-pro' ),
		'section'     => 'fotografie_footer_editor_options',
		'type'        => 'textarea',
	) );

	$wp_customize->add_setting( 'fotografie_reset_footer_content', array(
		'sanitize_callback' => 'fotografie_sanitize_checkbox',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( 'fotografie_reset_footer_content', array(
		'label'     => esc_html__( 'Check to reset Footer Content', 'fotografie-pro' ),
		'section'   => 'fotografie_footer_editor_options',
		'type'      => 'checkbox',
	) );

	// Layout Options
	$wp_customize->add_section( 'fotografie_layout_options', array(
		'title' => esc_html__( 'Layout Options', 'fotografie-pro' ),
		'panel' => 'fotografie_theme_options',
	) );

	/* Layout Type */
	$wp_customize->add_setting( 'fotografie_layout_type', array(
		'default'           => 'boxed',
		'sanitize_callback' => 'fotografie_sanitize_select',
	) );

	$wp_customize->add_control( 'fotografie_layout_type', array(
		'label'    => esc_html__( 'Site Layout', 'fotografie-pro' ),
		'section'  => 'fotografie_layout_options',
		'type'     => 'radio',
		'choices'  => array(
			'fluid' => esc_html__( 'Fluid', 'fotografie-pro' ),
			'boxed' => esc_html__( 'Boxed', 'fotografie-pro' ),
		),
	) );

	/* Default Layout */
	$wp_customize->add_setting( 'fotografie_default_layout', array(
		'default'           => 'no-sidebar',
		'sanitize_callback' => 'fotografie_sanitize_select',
	) );

	$wp_customize->add_control( 'fotografie_default_layout', array(
		'description' => esc_html__( 'Layout for Singular Post Types like Post, Page', 'fotografie-pro' ),
		'label'       => esc_html__( 'Singular Content Layout', 'fotografie-pro' ),
		'section'     => 'fotografie_layout_options',
		'type'        => 'radio',
		'choices'     => array(
			'left-sidebar'                  => esc_html__( 'Left Sidebar ( Primary Sidebar, Content )', 'fotografie-pro' ),
			'no-sidebar'                    => esc_html__( 'No Sidebar', 'fotografie-pro' ),
			'no-sidebar-full-width'         => esc_html__( 'No Sidebar: Full Width', 'fotografie-pro' ),
			'no-sidebar-full-content-width' => esc_html__( 'No Sidebar: Full Content Width', 'fotografie-pro' ),
			'right-sidebar'                 => esc_html__( 'Right Sidebar ( Content, Primary Sidebar )', 'fotografie-pro' ),
		),
	) );

	// Single page/Post Layout.
	$wp_customize->add_setting( 'fotografie_singular_image', array(
		'default'           => 'enable',
		'sanitize_callback' => 'fotografie_sanitize_select',
	) );

	$wp_customize->add_control( 'fotografie_singular_image', array(
		'label'       => esc_html__( 'Single Page/Post Image', 'fotografie-pro' ),
		'section'     => 'fotografie_layout_options',
		'type'        => 'radio',
		'choices'     => array(
			'enable'  => esc_html__( 'Enable', 'fotografie-pro' ),
			'disable' => esc_html__( 'Disable', 'fotografie-pro' ),
		),
	) );

	// Excerpt Options.
	$wp_customize->add_section( 'fotografie_excerpt_options', array(
		'panel'     => 'fotografie_theme_options',
		'title'     => esc_html__( 'Excerpt Options', 'fotografie-pro' ),
	) );

	$wp_customize->add_setting( 'fotografie_excerpt_length', array(
		'default'           => '45',
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( 'fotografie_excerpt_length', array(
		'description' => esc_html__( 'Excerpt length. Default is 45 words', 'fotografie-pro' ),
		'input_attrs' => array(
			'min'   => 10,
			'max'   => 200,
			'step'  => 5,
			'style' => 'width: 60px;',
			),
		'label'    => esc_html__( 'Excerpt Length (words)', 'fotografie-pro' ),
		'section'  => 'fotografie_excerpt_options',
		'type'     => 'number',
		)
	);

	$wp_customize->add_setting( 'fotografie_excerpt_more_text', array(
		'default'           => esc_html__( 'Continue reading', 'fotografie-pro' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'fotografie_excerpt_more_text', array(
		'label'    => esc_html__( 'Read More Text', 'fotografie-pro' ),
		'section'  => 'fotografie_excerpt_options',
		'type'     => 'text',
	) );

	// Comment Option.
	$wp_customize->add_section( 'fotografie_comment_option', array(
		'description'   => esc_html__( 'Comments can also be disabled on a per post/page basis when creating/editing posts/pages.', 'fotografie-pro' ),
		'panel'         => 'fotografie_theme_options',
		'title'         => esc_html__( 'Comment Options', 'fotografie-pro' ),
	) );

	$wp_customize->add_setting( 'fotografie_comment_option', array(
		'default'           => 'use-wordpress-setting',
		'sanitize_callback' => 'fotografie_sanitize_select',
	) );

	$wp_customize->add_control( 'fotografie_comment_option', array(
			'choices'   => fotografie_comment_options(),
			'label'     => __( 'Comment Option', 'fotografie-pro' ),
			'section'   => 'fotografie_comment_option',
			'type'      => 'select',
	) );

	$wp_customize->add_setting( 'fotografie_website_field', array(
		'sanitize_callback' => 'fotografie_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'fotografie_website_field', array(
		'label'     => esc_html__( 'Check to Disable Website Field', 'fotografie-pro' ),
		'section'   => 'fotografie_comment_option',
		'type'      => 'checkbox',
	) );

	/* Feed Redirect */
	$wp_customize->add_section( 'fotografie_feed_redirect_options', array(
		'title' => esc_html__( 'Feed Redirect', 'fotografie-pro' ),
		'description'   => esc_html__( 'If your custom feed(s) are not handled by Feedblitz or Feedburner, do not use the redirect options.', 'fotografie-pro' ),
		'panel' => 'fotografie_theme_options',
	) );

	$wp_customize->add_setting( 'fotografie_feed_redirect', array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'fotografie_feed_redirect', array(
		'label'    => esc_html__( 'Feed Redirect', 'fotografie-pro' ),
		'section'  => 'fotografie_feed_redirect_options',
	) );
	/* Feed Redirect End */

	// Homepage / Frontpage Options.
	$wp_customize->add_section( 'fotografie_homepage_options', array(
		'description' => esc_html__( 'Only posts that belong to the categories selected here will be displayed on the front page', 'fotografie-pro' ),
		'panel'       => 'fotografie_theme_options',
		'title'       => esc_html__( 'Homepage / Frontpage Options', 'fotografie-pro' ),
	) );

	$wp_customize->add_setting( 'fotografie_disable_homepage_posts', array(
		'sanitize_callback' => 'fotografie_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'fotografie_disable_homepage_posts', array(
		'label'   => esc_html__( 'Check to disable default Latest Posts/Static Page Content', 'fotografie-pro' ),
		'section' => 'fotografie_homepage_options',
		'type'    => 'checkbox',
	) );

	$wp_customize->add_setting( 'fotografie_latest_posts_title', array(
		'default'           => esc_html__( 'News', 'fotografie-pro' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'fotografie_latest_posts_title', array(
		'label'   => esc_html__( 'Latest Posts Title', 'fotografie-pro' ),
		'section' => 'fotografie_homepage_options',
	) );

	$wp_customize->add_setting( 'fotografie_front_page_category', array(
		'default'           => array(),
		'sanitize_callback' => 'fotografie_sanitize_category_list',
	) );

	$wp_customize->add_control( new Fotografie_Multi_Category_Control( $wp_customize, 'fotografie_front_page_category', array(
		'active_callback' => 'fotografie_is_homepage_posts_enabled',
		'label'           => esc_html__( 'Select Categories', 'fotografie-pro' ),
		'name'            => 'fotografie_front_page_category',
		'section'         => 'fotografie_homepage_options',
		'type'            => 'dropdown-categories',
	) ) );

    // Disable Recent post in static frontpage
    $wp_customize->add_setting( 'fotografie_enable_static_page_posts', array(
        'sanitize_callback' => 'fotografie_sanitize_checkbox',
    ) );

    $wp_customize->add_control( 'fotografie_enable_static_page_posts', array(
        'label'           => esc_html__( 'Check to Enable Recent Posts on Static Page', 'fotografie-pro' ),
        'section'         => 'fotografie_homepage_options',
        'type'            => 'checkbox',
    ) );

	// Pagination Options.
	$pagination_type = get_theme_mod( 'fotografie_pagination_type', 'default' );

	$nav_desc = '';

	/**
	* Check if navigation type is Jetpack Infinite Scroll and if it is enabled
	*/
	$nav_desc = sprintf(
		wp_kses(
			__( 'Infinite Scroll Options requires %1$sJetPack Plugin%2$s with Infinite Scroll module Enabled.', 'fotografie-pro' ),
			array(
				'a' => array(
					'href' => array(),
					'target' => array(),
				),
				'br'=> array()
			)
		),
		'<a target="_blank" href="https://wordpress.org/plugins/jetpack/">',
		'</a>'
	);

	$nav_desc .= '&nbsp;' . sprintf(
		wp_kses(
			__( 'Once Jetpack is installed, Infinite Scroll Settings can be found %1$shere%2$s', 'fotografie-pro' ),
			array(
				'a' => array(
					'href' => array(),
					'target' => array(),
				),
				'br'=> array()
			)
		),
		'<a target="_blank" href="' . esc_url( admin_url( 'admin.php?page=jetpack#/settings' ) ) . '">',
		'</a>'
	);

	$wp_customize->add_section( 'fotografie_pagination_options', array(
		'description'   => $nav_desc,
		'panel'         => 'fotografie_theme_options',
		'title'         => esc_html__( 'Pagination Options', 'fotografie-pro' ),
	) );

	$wp_customize->add_setting( 'fotografie_pagination_type', array(
		'default'           => 'default',
		'sanitize_callback' => 'fotografie_sanitize_select',
	) );

	$wp_customize->add_control( 'fotografie_pagination_type', array(
		'choices'  => fotografie_get_pagination_types(),
		'label'    => esc_html__( 'Pagination type', 'fotografie-pro' ),
		'section'  => 'fotografie_pagination_options',
		'type'     => 'select',
	) );

	// For WooCommerce layout: fotografie_woocommerce_layout, check woocommerce-options.php.
	/* Scrollup Options */
	$wp_customize->add_section( 'fotografie_scrollup', array(
		'panel'    => 'fotografie_theme_options',
		'title'    => esc_html__( 'Scrollup Options', 'fotografie-pro' ),
	) );

	$wp_customize->add_setting( 'fotografie_disable_scrollup', array(
		'sanitize_callback' => 'fotografie_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'fotografie_disable_scrollup', array(
		'label'     => esc_html__( 'Disable Scroll Up', 'fotografie-pro' ),
		'section'   => 'fotografie_scrollup',
		'type'      => 'checkbox',
	) );

	// Update Notifier.
	$wp_customize->add_section( 'Fotografie_Update_notifier', array(
		'title'    => esc_html__( 'Update Notifier', 'fotografie-pro' ),
		'panel'    => 'fotografie_theme_options',
	) );

	$wp_customize->add_setting( 'Fotografie_Update_notifier', array(
		'sanitize_callback' => 'fotografie_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'Fotografie_Update_notifier', array(
		'label'     => esc_html__( 'Check to disable update notifications', 'fotografie-pro' ),
		'section'   => 'Fotografie_Update_notifier',
		'type'      => 'checkbox',
	) );
}
add_action( 'customize_register', 'fotografie_theme_options' );


/**
 * Returns an array of avaliable fonts registered for Fotografie Pro
 *
 * @since Fotografie Pro 1.1
 */
function fotografie_avaliable_fonts() {
	$avaliable_fonts = array(
		'arial-black' => array(
			'value' => 'arial-black',
			'label' => '"Arial Black", Gadget, sans-serif',
		),
		'allan' => array(
			'value' => 'allan',
			'label' => '"Allan", sans-serif',
		),
		'allerta' => array(
			'value' => 'allerta',
			'label' => '"Allerta", sans-serif',
		),
		'amaranth' => array(
			'value' => 'amaranth',
			'label' => '"Amaranth", sans-serif',
		),
		'amatic-sc' => array(
			'value' => 'amatic-sc',
			'label' => '"Amatic SC", cursive',
		),
		'arial' => array(
			'value' => 'arial',
			'label' => 'Arial, Helvetica, sans-serif',
		),
		'bitter' => array(
			'value' => 'bitter',
			'label' => '"Bitter", sans-serif',
		),
		'cabin' => array(
			'value' => 'cabin',
			'label' => '"Cabin", sans-serif',
		),
		'cantarell' => array(
			'value' => 'cantarell',
			'label' => '"Cantarell", sans-serif',
		),
		'century-gothic' => array(
			'value' => 'century-gothic',
			'label' => '"Century Gothic", sans-serif',
		),
		'courier-new' => array(
			'value' => 'courier-new',
			'label' => '"Courier New", Courier, monospace',
		),
		'crimson-text' => array(
			'value' => 'crimson-text',
			'label' => '"Crimson Text", sans-serif',
		),
		'cuprum' => array(
			'value' => 'cuprum',
			'label' => '"Cuprum", sans-serif',
		),
		'dancing-script' => array(
			'value' => 'dancing-script',
			'label' => '"Dancing Script", sans-serif',
		),
		'droid-sans' => array(
			'value' => 'droid-sans',
			'label' => '"Droid Sans", sans-serif',
		),
		'droid-serif' => array(
			'value' => 'droid-serif',
			'label' => '"Droid Serif", sans-serif',
		),
		'exo' => array(
			'value' => 'exo',
			'label' => '"Exo", sans-serif',
		),
		'exo-2' => array(
			'value' => 'exo-2',
			'label' => '"Exo 2", sans-serif',
		),
		'georgia' => array(
			'value' => 'georgia',
			'label' => 'Georgia, "Times New Roman", Times, serif',
		),
		'helvetica' => array(
			'value' => 'helvetica',
			'label' => 'Helvetica, "Helvetica Neue", Arial, sans-serif',
		),
		'helvetica-neue' => array(
			'value' => 'helvetica-neue',
			'label' => '"Helvetica Neue",Helvetica,Arial,sans-serif',
		),
		'istok-web' => array(
			'value' => 'istok-web',
			'label' => '"Istok Web", sans-serif',
		),
		'impact' => array(
			'value' => 'impact',
			'label' => 'Impact, Charcoal, sans-serif',
		),
		'josefin-sans' => array(
			'value' => 'josefin-sans',
			'label' => '"Josefin Sans", sans-serif',
		),
		'lato' => array(
			'value' => 'lato',
			'label' => '"Lato", sans-serif',
		),
		'lucida-sans-unicode' => array(
			'value' => 'lucida-sans-unicode',
			'label' => '"Lucida Sans Unicode", "Lucida Grande", sans-serif',
		),
		'lucida-grande' => array(
			'value' => 'lucida-grande',
			'label' => '"Lucida Grande", "Lucida Sans Unicode", sans-serif',
		),
		'lobster' => array(
			'value' => 'lobster',
			'label' => '"Lobster", sans-serif',
		),
		'lora' => array(
			'value' => 'lora',
			'label' => '"Lora", serif',
		),
		'monaco' => array(
			'value' => 'monaco',
			'label' => 'Monaco, Consolas, "Lucida Console", monospace, sans-serif',
		),
		'montserrat' => array(
			'value' => 'montserrat',
			'label' => '"Montserrat", sans-serif',
		),
		'nobile' => array(
			'value' => 'nobile',
			'label' => '"Nobile", sans-serif',
		),
		'noto-serif' => array(
			'value' => 'noto-serif',
			'label' => '"Noto Serif", serif',
		),
		'neuton' => array(
			'value' => 'neuton',
			'label' => '"Neuton", serif',
		),
		'open-sans' => array(
			'value' => 'open-sans',
			'label' => '"Open Sans", sans-serif',
		),
		'oswald' => array(
			'value' => 'oswald',
			'label' => '"Oswald", sans-serif',
		),
		'palatino' => array(
			'value' => 'palatino',
			'label' => 'Palatino, "Palatino Linotype", "Book Antiqua", serif',
		),
		'patua-one' => array(
			'value' => 'patua-one',
			'label' => '"Patua One", sans-serif',
		),
		'playfair-display' => array(
			'value' => 'playfair-display',
			'label' => '"Playfair Display", sans-serif',
		),
		'pt-sans' => array(
			'value' => 'pt-sans',
			'label' => '"PT Sans", sans-serif',
		),
		'pt-serif' => array(
			'value' => 'pt-serif',
			'label' => '"PT Serif", serif',
		),
		'quattrocento-sans' => array(
			'value' => 'quattrocento-sans',
			'label' => '"Quattrocento Sans", sans-serif',
		),
		'roboto' => array(
			'value' => 'roboto',
			'label' => '"Roboto", sans-serif',
		),
		'roboto-slab' => array(
			'value' => 'roboto-slab',
			'label' => '"Roboto Slab", serif',
		),
		'rubik' => array(
			'value' => 'rubik',
			'label' => '"Rubik", serif',
		),
		'sans-serif' => array(
			'value' => 'sans-serif',
			'label' => 'Sans Serif, Arial',
		),
		'source-sans-pro' => array(
			'value' => 'source-sans-pro',
			'label' => '"Source Sans Pro", sans-serif',
		),
		'tahoma' => array(
			'value' => 'tahoma',
			'label' => 'Tahoma, Geneva, sans-serif',
		),
		'trebuchet-ms' => array(
			'value' => 'trebuchet-ms',
			'label' => '"Trebuchet MS", "Helvetica", sans-serif',
		),
		'times-new-roman' => array(
			'value' => 'times-new-roman',
			'label' => '"Times New Roman", Times, serif',
		),
		'ubuntu' => array(
			'value' => 'ubuntu',
			'label' => '"Ubuntu", sans-serif',
		),
		'varela' => array(
			'value' => 'varela',
			'label' => '"Varela", sans-serif',
		),
		'verdana' => array(
			'value' => 'verdana',
			'label' => 'Verdana, Geneva, sans-serif',
		),
		'yanone-kaffeesatz' => array(
			'value' => 'yanone-kaffeesatz',
			'label' => '"Yanone Kaffeesatz", sans-serif',
		),
	);

	return apply_filters( 'fotografie_avaliable_fonts', $avaliable_fonts );
}


/**
 * Returns an array of font family options
 *
 * @since Fotografie Pro 1.1
 */
function fotografie_font_family_options() {
	$options = array(
		'fotografie_body_font'         => array(
			'label'    => esc_html__( 'Default Font Family', 'fotografie-pro' ),
			'default'  => 'montserrat',
			'selector' => 'body, button, input, select, textarea',
		),
		'fotografie_title_font'        => array(
			'label'    => esc_html__( 'Site Title Font Family', 'fotografie-pro' ),
			'default'  => 'montserrat',
			'selector' => '.site-title',
		),
		'fotografie_tagline_font'      => array(
			'label'    => esc_html__( 'Site Tagline Font Family', 'fotografie-pro' ),
			'default'  => 'montserrat',
			'selector' => '.site-description',
		),
		'fotografie_headings_font'     => array(
			'label' => esc_html__( 'Headings Tags from h1 to h6 Font Family', 'fotografie-pro' ),
			'default' => 'montserrat',
			'selector' => 'h1, h2, h3, h4, h5, h6',
		),
		'fotografie_content_title_font' => array(
			'label'    => esc_html__( 'Content Title Font Family', 'fotografie-pro' ),
			'default'  => 'montserrat',
			'selector' => '.page-title, #main .entry-title, #main .entry-subtitle',
		),
		'fotografie_content_font'       => array(
			'label'    => esc_html__( 'Content Body Font Family', 'fotografie-pro' ),
			'default'  => 'montserrat',
			'selector' => '#main .entry-content, #main .entry-summary',
		),
	);

	return apply_filters( 'fotografie_font_family_options', $options );
}
