<?php
/**
 * The template for displaying meta box in page/post
 *
 * This adds Layout Options, Select Sidebar, Header Freatured Image Options, Single Page/Post Image Layout
 * This is only for the design purpose and not used to save any content
 *
 * @package Fotografie Pro
 */


/**
 * Class to Add, Render and save metabox options
 *
 * @since Fotografie Pro 1.0
 */
class Fotografie_Metabox {
	private $meta_box;

	/**
	 * Constructor
	 *
	 * @since Fotografie Pro 1.0
	 *
	 * @access public
	 *
	 */
	public function __construct( $meta_box_id, $meta_box_title, $post_type ) {

		$this->meta_box = array(
			'id' 		=> $meta_box_id,
			'title' 	=> $meta_box_title,
			'post_type' => $post_type,
		);

		// Add metaboxes.
		add_action( 'add_meta_boxes', array( $this, 'add' ) );

		add_action( 'save_post', array( $this, 'save' ) );

		}

	/**
	 * Add Meta Box for multiple post types.
	 *
	 * @param [string] $post_type Post Type.
	 */
	public function add( $post_type ) {
		if ( in_array( $post_type, $this->meta_box['post_type'] ) ) {
			add_meta_box( $this->meta_box['id'], $this->meta_box['title'], array( $this, 'show' ), $post_type,'side' );
		}
	}

	/**
	 * Renders metabox
	 */
	public function show() {
		global $post;

		$sidebar_options = array(
			'main-sidebar' => array(
				'id'		=> 'fotografie-sidebar-options',
				'value' 	=> 'default-sidebar',
				'label' 	=> esc_html__( 'Default Sidebar', 'fotografie-pro' ),
			),
			'optional-sidebar-one' => array(
				'id' 	=> 'fotografie-sidebar-options',
				'value' => 'optional-sidebar-one',
				'label' => esc_html__( 'Optional Sidebar One', 'fotografie-pro' ),
			),
			'optional-sidebar-two' => array(
				'id' 	=> 'fotografie-sidebar-options',
				'value' => 'optional-sidebar-two',
				'label' => esc_html__( 'Optional Sidebar Two', 'fotografie-pro' ),
			),
			'optional-sidebar-three' => array(
				'id' 	=> 'fotografie-sidebar-options',
				'value' => 'optional-sidebar-three',
				'label' => esc_html__( 'Optional Sidebar three', 'fotografie-pro' ),
			),
		);

		$singular_image = array(
			'default' => array(
				'id' 	=> 'fotografie-single-image',
				'value' => 'default',
				'label' => esc_html__( 'Default', 'fotografie-pro' ),
			),
			'post-thumbnail' => array(
				'id' 	=> 'fotografie-single-image',
				'value' => 'post-thumbnail',
				'label' => esc_html__( 'Featured Image ( 1148x574 )', 'fotografie-pro' ),
			),
			'full' => array(
				'id' 	=> 'fotografie-single-image',
				'value' => 'full',
				'label' => esc_html__( 'Full Image', 'fotografie-pro' ),
			),
			'fotografie-header-image' => array(
				'id' 	=> 'fotografie-header-image',
				'value' => 'fotografie-header-image',
				'label' => esc_html__( 'Header Image ( 1920x689 )', 'fotografie-pro' ),
			),
			'fotografie-slider' => array(
				'id' 	=> 'fotografie-single-image',
				'value' => 'fotografie-slider',
				'label' => esc_html__( 'Slider Image ( 1920x1080 )', 'fotografie-pro' ),
			),
			'disable' => array(
				'id' 	=> 'fotografie-single-image',
				'value' => 'disable',
				'label' => esc_html__( 'Disable', 'fotografie-pro' ),
			),
		);

		$header_image = array(
			'default' => array(
				'id' 	=> 'fotografie-header-image',
				'value' => 'default',
				'label' => esc_html__( 'Default', 'fotografie-pro' ),
			),
			'enable' => array(
				'id' 	=> 'fotografie-header-image',
				'value' => 'enable',
				'label' => esc_html__( 'Enable', 'fotografie-pro' ),
			),
			'disable' => array(
				'id' 	=> 'fotografie-header-image',
				'value' => 'disable',
				'label' => esc_html__( 'Disable', 'fotografie-pro' ),
			),
		);

		// Use nonce for verification.
		wp_nonce_field( basename( __FILE__ ), 'fotografie_custom_meta_box_nonce' );

		// Begin the field table and loop.
		?>
		<p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="fotografie-sidebar-options"><?php esc_html_e( 'Select Sidebar', 'fotografie-pro' ); ?></label></p>
		<select class="widefat" name="fotografie-sidebar-options" id="fotografie-sidebar-options">
			 <?php
				$meta_value = get_post_meta( $post->ID, 'fotografie-sidebar-options', true );
				
				if ( empty( $meta_value ) ){
					$meta_value='default';
				}
				
				foreach ( $sidebar_options as $field =>$label ) {	
				?>
					<option value="<?php echo esc_attr( $label['value'] ); ?>" <?php selected( $meta_value, $label['value'] ); ?>><?php echo esc_html( $label['label'] ); ?></option>
				<?php
				} // end foreach
			?>
		</select>

		<p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="fotografie-single-image"><?php esc_html_e( 'Single Page/Post Image', 'fotografie-pro' ); ?></label></p>
		<select class="widefat" name="fotografie-single-image" id="fotografie-single-image">
			 <?php
				$meta_value = get_post_meta( $post->ID, 'fotografie-single-image', true );
				
				if ( empty( $meta_value ) ){
					$meta_value='default';
				}
				
				foreach ( $singular_image as $field =>$label ) {	
				?>
					<option value="<?php echo esc_attr( $label['value'] ); ?>" <?php selected( $meta_value, $label['value'] ); ?>><?php echo esc_html( $label['label'] ); ?></option>
				<?php
				} // end foreach
			?>
		</select>
		<p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="fotografie-header-image"><?php esc_html_e( 'Header Featured Image Options', 'fotografie-pro' ); ?></label></p>
		<select class="widefat" name="fotografie-header-image" id="fotografie-header-image">
			 <?php
				$meta_value = get_post_meta( $post->ID, 'fotografie-header-image', true );
				
				if ( empty( $meta_value ) ){
					$meta_value='default';
				}
				
				foreach ($header_image as $field =>$label ) {	
				?>
				<option value="<?php echo esc_attr( $label['value'] ); ?>" <?php selected( $meta_value, $label['value'] ); ?>><?php echo esc_html( $label['label'] ); ?></option>
					
				<?php
				} // end foreach
			?>
		</select>
		<?php
	}

	/**
	 * Save custom metabox data
	 *
	 * @action save_post
	 *
	 * @since Fotografie Pro 1.0
	 *
	 * @access public
	 */
	public function save( $post_id ) {
		global $post_type;

		$post_type_object = get_post_type_object( $post_type );

		if ( ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )                      // Check Autosave
		|| ( ! isset( $_POST['post_ID'] ) || $post_id != $_POST['post_ID'] )        // Check Revision
		|| ( ! in_array( $post_type, $this->meta_box['post_type'] ) )                  // Check if current post type is supported.
		|| ( ! check_admin_referer( basename( __FILE__ ), 'fotografie_custom_meta_box_nonce') )    // Check nonce - Security
		|| ( ! current_user_can( $post_type_object->cap->edit_post, $post_id ) ) )  // Check permission
		{
		  return $post_id;
		}

		$value = $_POST['fotografie-sidebar-options'];

		if ( '' === $value || is_array( $value ) ) {
			return;
		} else {
			delete_post_meta( $post_id, 'fotografie-sidebar-options' );

			if ( ! update_post_meta( $post_id, 'fotografie-sidebar-options', sanitize_key( $value ) ) ) {
				add_post_meta( $post_id, 'fotografie-sidebar-options', sanitize_key( $value ), true );
			}
		}

		$value = $_POST['fotografie-single-image'];

		if ( '' === $value || is_array( $value ) ) {
			return;
		} else {
			delete_post_meta( $post_id, 'fotografie-single-image' );

			if ( ! update_post_meta( $post_id, 'fotografie-single-image', sanitize_key( $value ) ) ) {
				add_post_meta( $post_id, 'fotografie-single-image', sanitize_key( $value ), true );
			}
		}

		$value = $_POST['fotografie-header-image'];

		if ( '' === $value || is_array( $value ) ) {
			return;
		} else {
			delete_post_meta( $post_id, 'fotografie-header-image' );

			if ( ! update_post_meta( $post_id, 'fotografie-header-image', sanitize_key( $value ) ) ) {
				add_post_meta( $post_id, 'fotografie-header-image', sanitize_key( $value ), true );
			}
		}
	}
}

$fotografie_metabox = new Fotografie_Metabox(
	'fotografie-options', 					//metabox id
	esc_html__( 'Fotografie Pro Options', 'fotografie-pro' ), //metabox title
	array( 'page', 'post' )				//metabox post types
);
