<?php
/**
 * Featured Embed Widget
 *
 * @package Fotografie Pro
 */


/**
 * Makes a custom Widget for Displaying Embed Codes
 *
 * Learn more: http://codex.wordpress.org/Widgets_API#Developing_Widgets
 *
 * @package Fotografie Pro
 */
class Fotografie_Featured_Embed_Widget extends WP_Widget {

	/**
	 * Holds widget settings defaults, populated in constructor.
	 *
	 * @var array
	 */
	protected $defaults;

	function __construct() {

		$this->defaults = array(
			'title'           => '',
			'items_number'    => 1,
			'layout'          => 'one-column',
		);

		$widget_ops = array(
			'classname'   => 'ct-featured-embed ctfeaturedembed',
			'description' => esc_html__( 'Use this widget to add Featured Embed Codes', 'fotografie-pro' ),
		);

		$control_ops = array(
			'id_base' => 'ct-featured-embed',
		);

		parent::__construct(
			'ct-featured-embed', // Base ID
			__( 'CT: Featured Embeds', 'fotografie-pro' ), // Name
			$widget_ops,
			$control_ops
		);
	}

	/**
	 * Creates the form for the widget in the back-end which includes the Title , adcode, code, alt
	 * $instance Current settings
	 */
	function form($instance) {
		//* Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );
		?>
        <p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title', 'fotografie-pro' ); ?>:</label>
			<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" class="widefat" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'layout' ) ); ?>"><?php esc_html_e( 'Layout', 'fotografie-pro' ); ?>:</label>
			<select id="<?php echo esc_attr( $this->get_field_id( 'layout' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'layout' ) ); ?>" class="widefat">
				<?php
					$post_type_choices = array(
						'one-column'   => esc_html__( '1 Column', 'fotografie-pro' ),
						'two-columns'   => esc_html__( '2 Column', 'fotografie-pro' ),
						'three-columns' => esc_html__( '3 Column', 'fotografie-pro' ),
						'four-columns'  => esc_html__( '4 Column', 'fotografie-pro' ),
					);

				foreach ( $post_type_choices as $key => $value ) {
					echo '<option value="' . $key . '" '. selected( $key, $instance['layout'], false ) .'>' . $value .'</option>';
				}
				?>
			</select>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'items_number' ) ); ?>"><?php esc_html_e( 'No. of Items', 'fotografie-pro' ); ?>:</label>
			<input type="number" id="<?php echo esc_attr( $this->get_field_id( 'items_number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'items_number' ) ); ?>" value="<?php echo absint( $instance['items_number'] ); ?>" class="small-text" min="1" />
			<br>
			<span class="description"><?php esc_html_e( 'Please save the widget once No. of items is changed to reflect the changes', 'fotografie-pro' ); ?></span>
		</p>

		<?php for( $i=1; $i<= absint( $instance['items_number'] ); $i++ ) { ?>

		<?php
			$code =  isset( $instance['code' . '_' .  $i] ) ? $instance['code' . '_' .  $i] : '';
		?>

		<p>
        	<label for="<?php echo esc_attr( $this->get_field_id( 'code' . '_' .  $i ) ); ?>">
        		<?php printf( esc_html__( 'Code %1s', 'fotografie-pro' ), $i ); ?>
        	</label>

        	<textarea class="ct-textarea" name="<?php echo esc_attr( $this->get_field_name( 'code' . '_' .  $i ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'code' . '_' .  $i ) ); ?>"><?php echo esc_textarea( $code ); ?></textarea>
        </p>
	    <?php } //end for ?>

        <?php
	}

	/**
	 * update the particular instant
	 *
	 * This function should check that $new_instance is set correctly.
	 * The newly calculated value of $instance should be returned.
	 * If "false" is returned, the instance won't be saved/updated.
	 *
	 * $new_instance New settings for this instance as input by the user via form()
	 * $old_instance Old settings for this instance
	 * Settings to save or bool false to cancel saving
	 */
	function update( $new_instance, $old_instance ) {
		$instance 				= $old_instance;

		$instance['title']           = sanitize_text_field( $new_instance['title'] );
		$instance['items_number']    = absint( $new_instance['items_number'] );
		$instance['layout']          = sanitize_key( $new_instance['layout'] );

		for( $i=1; $i<= absint( $instance['items_number'] ); $i++ ) {
			$instance['code' . '_' .  $i]
				= wp_kses_stripslashes( $new_instance['code' . '_' .  $i] );
		}

		return $instance;
	}

	/**
	 * Displays the Widget in the front-end.
	 *
	 * $args Display arguments including before_title, after_title, before_widget, and after_widget.
	 * $instance The settings for the particular instance of the widget
	 */
	function widget( $args, $instance ) {
		// Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );

		echo $args['before_widget'];

		// Set up the author bio
		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $args['after_title'];
		}


		$class[] = 'featured-embed-wrap';

		if ( 'one-column' != $instance['layout'] ) {
			$class[] = $instance['layout'];
			$class[] = 'columns';
		}

		echo '<div class="' . esc_attr( implode( ' ', $class ) ) . '">';

		for( $i=1; $i<= absint( $instance['items_number'] ); $i++ ) {
			$code =  isset( $instance['code' . '_' .  $i] ) ? $instance['code' . '_' .  $i] : '';

			if ( '' != $code ) {
				echo '<div class="type-embed featured-embed-' . $i . ' hentry">';

				echo do_shortcode( $code );

				echo '</div><!-- .type-embed -->';
			}
		}

		echo '</div><!-- .featured-embed-wrap -->';

		echo $args['after_widget'];
	}

}

/**
 * Initialize Widget
 */
function fotografie_featured_embed_widget_init() {
	register_widget( 'Fotografie_Featured_Embed_Widget' );
}
add_action( 'widgets_init', 'fotografie_featured_embed_widget_init' );
