<?php
/**
 * Featured Image Widget
 *
 * @package Fotografie Pro
 */


/**
 * Makes a custom Widget for Displaying Featured Images
 *
 * Learn more: http://codex.wordpress.org/Widgets_API#Developing_Widgets
 *
 * @package Fotografie Pro
 */
class Fotografie_Featured_Image_Widget extends WP_Widget {

	/**
	 * Holds widget settings defaults, populated in constructor.
	 *
	 * @var array
	 */
	protected $defaults;

	function __construct() {

		$this->defaults = array(
			'title'           => '',
			'items_number'    => 1,
			'layout'          => 'one-column',
			'image_alignment' => 'top',
		);

		$widget_ops = array(
			'classname'   => 'ct-featured-image ctfeaturedpostpageimage',
			'description' => esc_html__( 'Use this widget to add Featured Image', 'fotografie-pro' ),
		);

		$control_ops = array(
			'id_base' => 'ct-featured-image',
		);

		parent::__construct(
			'ct-featured-image', // Base ID
			__( 'CT: Featured Images', 'fotografie-pro' ), // Name
			$widget_ops,
			$control_ops
		);
	}

	/**
	 * Creates the form for the widget in the back-end which includes the Title , adcode, image, alt
	 * $instance Current settings
	 */
	function form($instance) {
		//* Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );
		?>
        <p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title', 'fotografie-pro' ); ?>:</label>
			<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" class="widefat" />
		</p>

        <p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'layout' ) ); ?>"><?php esc_html_e( 'Layout', 'fotografie-pro' ); ?>:</label>
			<select id="<?php echo esc_attr( $this->get_field_id( 'layout' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'layout' ) ); ?>" class="widefat">
				<?php
					$post_type_choices = array(
						'one-column'    => esc_html__( '1 Column', 'fotografie-pro' ),
						'two-columns'   => esc_html__( '2 Column', 'fotografie-pro' ),
						'three-columns' => esc_html__( '3 Column', 'fotografie-pro' ),
						'four-columns'  => esc_html__( '4 Column', 'fotografie-pro' ),
					);

				foreach ( $post_type_choices as $key => $value ) {
					echo '<option value="' . $key . '" '. selected( $key, $instance['layout'], false ) .'>' . $value .'</option>';
				}
				?>
			</select>
		</p>

        <p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'items_number' ) ); ?>"><?php esc_html_e( 'No. of Items', 'fotografie-pro' ); ?>:</label>
			<input type="number" id="<?php echo esc_attr( $this->get_field_id( 'items_number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'items_number' ) ); ?>" value="<?php echo absint( $instance['items_number'] ); ?>" class="small-text" min="1" />
			<br>
			<span class="description"><?php esc_html_e( 'Please save the widget once No. of items is changed to reflect the changes', 'fotografie-pro' ); ?></span>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'image_alignment' ) ); ?>"><?php esc_html_e( 'Image Alignment', 'fotografie-pro' ); ?>:</label>
			<select id="<?php echo esc_attr( $this->get_field_id( 'image_alignment' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'image_alignment' ) ); ?>" class="widefat">
				<?php
					$image_alignment_choices = array(
						'top'    => esc_html__( 'Top', 'fotografie-pro' ),
						'left'   => esc_html__( 'Left', 'fotografie-pro' ),
						'right'  => esc_html__( 'Right', 'fotografie-pro' ),
						'center' => esc_html__( 'Center', 'fotografie-pro' ),
					);

				foreach ( $image_alignment_choices as $key => $value ) {
					echo '<option value="' . $key . '" '. selected( $key, $instance['image_alignment'], false ) .'>' . $value .'</option>';
				}
				?>
			</select>
		</p>

		<?php for( $i=1; $i<= absint( $instance['items_number'] ); $i++ ) { ?>

		<div class="ct-image-box">
			<?php
				$image_title
					=  isset( $instance['image_title' . '_' .  $i] ) ? $instance['image_title' . '_' .  $i] : '';

				$image
					=  isset( $instance['image' . '_' .  $i] ) ? $instance['image' . '_' .  $i] : '';
				$image_link
					=  isset( $instance['image_link' . '_' .  $i] ) ? $instance['image_link' . '_' .  $i] : '';
				$target
					=  isset( $instance['target' . '_' .  $i] ) ? $instance['target' . '_' .  $i] : '';
				$alt
					=  isset( $instance['alt' . '_' .  $i] ) ? $instance['alt' . '_' .  $i] : '';

				$content
					=  isset( $instance['content' . '_' .  $i] ) ? $instance['content' . '_' .  $i] : '';
			?>
			<h2> <?php printf( esc_html__( 'Image %1s', 'fotografie-pro' ), $i ); ?> </h2>

			<p>
	            <label for="<?php echo esc_attr( $this->get_field_id( 'image_title' . '_' .  $i ) ); ?>"><?php _e('Title:','fotografie-pro'); ?></label>
	        <input type="text" name="<?php echo esc_attr( $this->get_field_name('image_title' . '_' .  $i ) ); ?>" value="<?php echo esc_attr( $image_title ); ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'image_title' . '_' .  $i ) ); ?>" />
	        </p>

			<p>
	            <label for="<?php echo esc_attr( $this->get_field_id( 'image' . '_' .  $i ) ); ?>"><?php _e('Image Url:','fotografie-pro'); ?></label>
	        <input type="text" name="<?php echo esc_attr( $this->get_field_name( 'image' . '_' .  $i ) ); ?>" value="<?php echo esc_url( $image ); ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'image' . '_' .  $i ) ); ?>" />
	        </p>

	        <p>
	            <label for="<?php echo esc_attr( $this->get_field_id( 'image_link' . '_' .  $i ) ); ?>"><?php _e('Image Link:','fotografie-pro'); ?></label>
	            <input type="text" name="<?php echo esc_attr( $this->get_field_name( 'image_link' . '_' .  $i ) ); ?>" value="<?php echo esc_url( $image_link ); ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'image_link' . '_' .  $i ) ); ?>" />
	        </p>

	        <p>
	        	<input class="checkbox" type="checkbox" <?php checked( $target, true ) ?> id="<?php echo esc_attr( $this->get_field_id( 'target' . '_' .  $i ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'target' . '_' .  $i ) ); ?>" />
	        	<label for="<?php echo esc_attr( $this->get_field_id( 'target' . '_' .  $i ) ); ?>"><?php esc_html_e( 'Check to Open Link in new Tab/Window', 'fotografie-pro' ); ?></label><br />
	        </p>
	        <p>
	            <label for="<?php echo esc_attr( $this->get_field_id( 'alt' . '_' .  $i ) ); ?>"><?php _e('Alt text:','fotografie-pro'); ?></label>
	            <input type="text" name="<?php echo esc_attr( $this->get_field_name( 'alt' . '_' .  $i ) ); ?>" value="<?php echo esc_attr( $alt ) ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'alt' . '_' .  $i ) ); ?>" />
	        </p>

	        <p>
	            <label for="<?php echo esc_attr( $this->get_field_id( 'content' . '_' .  $i ) ); ?>"><?php esc_html_e( 'Content','fotografie-pro' ); ?></label>
	            <textarea class="ct-textarea" name="<?php echo esc_attr( $this->get_field_name( 'content' . '_' .  $i ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'content' . '_' .  $i ) ); ?>"><?php echo esc_textarea( $content ) ?></textarea>
	        </p>
	    </div> <!-- .ct-image-box -->
	    <?php } //end for ?>
        <?php
	}

	/**
	 * update the particular instant
	 *
	 * This function should check that $new_instance is set correctly.
	 * The newly calculated value of $instance should be returned.
	 * If "false" is returned, the instance won't be saved/updated.
	 *
	 * $new_instance New settings for this instance as input by the user via form()
	 * $old_instance Old settings for this instance
	 * Settings to save or bool false to cancel saving
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		$instance['title']           = sanitize_text_field( $new_instance['title'] );
		$instance['items_number']    = absint( $new_instance['items_number'] );
		$instance['layout']          = sanitize_key( $new_instance['layout'] );
		$instance['image_alignment'] = sanitize_key( $new_instance['image_alignment'] );

		for( $i=1; $i<= absint( $instance['items_number'] ); $i++ ) {
			$instance['image_title' . '_' .  $i]
				= sanitize_text_field( $new_instance['image_title' . '_' .  $i] );
			$instance['image' . '_' .  $i]
				= esc_url_raw( $new_instance['image' . '_' .  $i] );
			$instance['image_link' . '_' .  $i]
				= esc_url_raw( $new_instance['image_link' . '_' .  $i] );
			$instance[ 'target' . '_' .  $i]
				= fotografie_sanitize_checkbox( $new_instance['target' . '_' .  $i] );
			$instance['alt' . '_' .  $i]
				= sanitize_text_field( $new_instance['alt' . '_' .  $i] );
			$instance['content' . '_' .  $i]
				= wp_kses_post( $new_instance['content' . '_' .  $i] );
		}

		return $instance;
	}

	/**
	 * Displays the Widget in the front-end.
	 *
	 * $args Display arguments including before_title, after_title, before_widget, and after_widget.
	 * $instance The settings for the particular instance of the widget
	 */
	function widget( $args, $instance ) {
		// Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );

		echo $args['before_widget'];

		// Set up the author bio
		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $args['after_title'];
		}

		$class[] = 'featured-image-wrap';

		$class[] = $instance['image_alignment'];

		if ( 'one-column' != $instance['layout'] ) {
			$class[] = $instance['layout'];
			$class[] = 'columns';
		}

		echo '<div class="' . esc_attr( implode( ' ', $class ) ) . '">';

		for( $i=1; $i<= absint( $instance['items_number'] ); $i++ ) {

			$image_title
				=  isset( $instance['image_title' . '_' .  $i] ) ? $instance['image_title' . '_' .  $i] : '';
			$image
				=  isset( $instance['image' . '_' .  $i] ) ? $instance['image' . '_' .  $i] : '';
			$image_link
				=  isset( $instance['image_link' . '_' .  $i] ) ? $instance['image_link' . '_' .  $i] : '';
			$target
				=  isset( $instance['target' . '_' .  $i] ) ? $instance['target' . '_' .  $i] : '';
			$alt
				=  isset( $instance['alt' . '_' .  $i] ) ? $instance['alt' . '_' .  $i] : '';
			$content
				=  isset( $instance['content' . '_' .  $i] ) ? $instance['content' . '_' .  $i] : '';

			if( '' == $image && '' == $image_title && '' == $image_link ) {
				//Exit loop if all elements are empty
				break;
			}

			$base = '_self';

			if ( $target ) {
				$base = '_blank';
			}

			echo '<article class="type-image featured-image-' . $i . ' hentry">';

			if ( '' != $image ) {
				echo '<figure class="featured-image">';

				$image_output = '<img src="' . esc_url( $image ) . '" alt="' . esc_attr( $alt ) . '" />';

				if( '' != $image_link ) {
					echo '
					<a href="' . esc_url( $image_link ).'" target="' . esc_attr( $base ) . '">
						' . $image_output . '
					</a>';
				}
				else {
					echo $image_output;
				}

				echo '</figure>';
			}

			if ( '' != $image_title && '' != $content ) {
				echo '<div class="entry-container">';
			}

			if ( '' != $image_title ) {
				echo '
				<header class="entry-header">
					<h2 class="entry-title">';

				if( '' != $image_link ) {
					echo '<a href="' . esc_url( $image_link ) . '" title="'. esc_attr( $image_title ) .'">'. $image_title .'</a>';
				}
				else {
					echo $image_title;
				}

				echo '</h2></header>';
			}

			if ( '' != $content ) {
				echo '<div class="entry-content">';
				echo do_shortcode( $content );
				echo '</div><!-- .entry-content -->';

			}

			if ( '' != $image_title && '' != $content ) {
				echo '</div><!-- .entry-container -->';
			}

			echo '</article><!-- .type-image -->';
		}

		echo '</div><!-- .featured-image-wrap -->';

		echo $args['after_widget'];
	}

}

/**
 * Initialize Widget
 */
function fotografie_featured_image_widget_init() {
	register_widget( 'Fotografie_Featured_Image_Widget' );
}
add_action( 'widgets_init', 'fotografie_featured_image_widget_init' );
