<?php
/**
 * Featured Page Widget
 *
 * @package Fotografie Pro
 */


/**
 * Widget that shows selected page content and the title.
 * Construct the widget.
 * i.e. Name, description and control options.
 * Has form to ask the title, select page
 * In the display function we show the title and selected page's content.
 * If the title is not set, it shows the page title as the title.
 *
 */
class Fotografie_Page_Widget extends WP_Widget {

	/**
	 * Holds widget settings defaults, populated in constructor.
	 *
	 * @var array
	 */
	protected $defaults;

	function __construct() {
		$this->defaults = array(
			'title'           => '',
			'page_id'         => '',
			'layout'     	  => 'one-column',
			'disable_image'   => 0,
			'image_alignment' => 'top',
			'image_size'      => '',
			'disable_title'   => 0,
			'content_type'    => 'excerpt',
			'content_limit'   => 200,
			'more_text'       => esc_html__( 'Continue reading', 'fotografie-pro' ),
		);

		$widget_ops = array(
			'classname'   => 'ct-featured-page ctfeaturedpage',
			'description' => esc_html__( 'Displays featured page with thumbnails', 'fotografie-pro' ),
		);

		$control_ops = array(
			'id_base' => 'ct-featured-page',
		);

		parent::__construct(
			'ct-featured-page', // Base ID
			__( 'CT: Featured Pages', 'fotografie-pro' ), // Name
			$widget_ops,
			$control_ops
		);
	}

 	function form( $instance ) {
 		//Defaults
 		$instance = wp_parse_args( (array) $instance, $this->defaults );
		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title', 'fotografie-pro' ); ?>:</label>
			<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" class="widefat" />
		</p>

        <p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'page_id' ) ); ?>"><?php esc_html_e( 'Page ID', 'fotografie-pro' ); ?>:</label>
			<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'page_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'page_id' ) ); ?>" value="<?php echo sanitize_text_field( $instance['page_id'] ); ?>" class="widefat"/>
			<span class="description"><?php esc_html_e( 'Separate Multiple Page IDs by ,(comma)', 'fotografie-pro' ); ?></span>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'layout' ) ); ?>"><?php esc_html_e( 'Layout', 'fotografie-pro' ); ?>:</label>
			<select id="<?php echo esc_attr( $this->get_field_id( 'layout' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'layout' ) ); ?>" class="widefat">
				<?php
					$post_type_choices = array(
						'one-column'   => esc_html__( '1 Column', 'fotografie-pro' ),
						'two-columns'   => esc_html__( '2 Column', 'fotografie-pro' ),
						'three-columns' => esc_html__( '3 Column', 'fotografie-pro' ),
						'four-columns'  => esc_html__( '4 Column', 'fotografie-pro' ),
					);

				foreach ( $post_type_choices as $key => $value ) {
					echo '<option value="' . $key . '" '. selected( $key, $instance['layout'], false ) .'>' . $value .'</option>';
				}
				?>
			</select>
		</p>

        <p>
        	<input class="checkbox" type="checkbox" <?php checked($instance['disable_image'], true) ?> id="<?php echo esc_attr( $this->get_field_id( 'disable_image' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'disable_image' ) ); ?>" />
        	<label for="<?php echo esc_attr( $this->get_field_id( 'disable_image' ) ); ?>"><?php esc_html_e( 'Check to Disable Image', 'fotografie-pro' ); ?></label><br />
        </p>

        <p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'image_alignment' ) ); ?>"><?php esc_html_e( 'Image Alignment', 'fotografie-pro' ); ?>:</label>
			<select id="<?php echo esc_attr( $this->get_field_id( 'image_alignment' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'image_alignment' ) ); ?>" class="widefat">
				<?php
					$image_alignment_choices = array(
						'top'    => esc_html__( 'Top', 'fotografie-pro' ),
						'left'   => esc_html__( 'Left', 'fotografie-pro' ),
						'right'  => esc_html__( 'Right', 'fotografie-pro' ),
						'center' => esc_html__( 'Center', 'fotografie-pro' ),
					);

				foreach ( $image_alignment_choices as $key => $value ) {
					echo '<option value="' . $key . '" '. selected( $key, $instance['image_alignment'], false ) .'>' . $value .'</option>';
				}
				?>
			</select>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'image_size' ) ); ?>"><?php esc_html_e( 'Image Size', 'fotografie-pro' ); ?>:</label>
			<select id="<?php echo esc_attr( $this->get_field_id( 'image_size' ) ); ?>" class="fotografie-image-size-selector" name="<?php echo esc_attr( $this->get_field_name( 'image_size' ) ); ?>">
				<?php
				$sizes = fotografie_get_additional_image_sizes();
				foreach( (array) $sizes as $name => $size )
					echo '<option value="'.esc_attr( $name ).'" '.selected( $name, $instance['image_size'], FALSE ).'>'.esc_html( $name ).' ( '.$size['width'].'x'.$size['height'].' )</option>';
				?>
			</select>
		</p>

		<p>
        	<input class="checkbox" type="checkbox" <?php checked($instance['disable_title'], true) ?> id="<?php echo esc_attr( $this->get_field_id( 'disable_title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'disable_title' ) ); ?>" />
        	<label for="<?php echo esc_attr( $this->get_field_id( 'disable_title' ) ); ?>"><?php esc_html_e( 'Check to Disable Title', 'fotografie-pro' ); ?></label><br />
        </p>

        <p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'content_type' ) ); ?>"><?php esc_html_e( 'Content Type', 'fotografie-pro' ); ?>:</label>
			<select id="<?php echo esc_attr( $this->get_field_id( 'content_type' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'content_type' ) ); ?>">
				<option value="content" <?php selected( 'content', $instance['content_type'] ); ?>><?php esc_html_e( 'Show Content', 'fotografie-pro' ); ?></option>
				<option value="excerpt" <?php selected( 'excerpt', $instance['content_type'] ); ?>><?php esc_html_e( 'Show Excerpt', 'fotografie-pro' ); ?></option>
				<option value="content-limit" <?php selected( 'content-limit', $instance['content_type'] ); ?>><?php esc_html_e( 'Show Content Limit', 'fotografie-pro' ); ?></option>
				<option value="" <?php selected( '', $instance['content_type'] ); ?>><?php esc_html_e( 'No Content', 'fotografie-pro' ); ?></option>
			</select>
			<br />
			<label for="<?php echo esc_attr( $this->get_field_id( 'content_limit' ) ); ?>"><?php esc_html_e( 'Limit content to', 'fotografie-pro' ); ?>
				<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'content_limit' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'content_limit' ) ); ?>" value="<?php echo esc_attr( intval( $instance['content_limit'] ) ); ?>" size="3" />
				<?php esc_html_e( 'characters', 'fotografie-pro' ); ?>
			</label>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'more_text' ) ); ?>"><?php esc_html_e( 'More Text (if applicable)', 'fotografie-pro' ); ?>:</label>
			<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'more_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'more_text' ) ); ?>" value="<?php echo esc_html( $instance['more_text'] ); ?>" />
		</p>
	<?php
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		$instance['title']           = sanitize_text_field( $new_instance['title'] );
		$instance['page_id']         = sanitize_text_field( $new_instance['page_id'] );
		$instance['layout']          = sanitize_key( $new_instance['layout'] );
		$instance['disable_image']   = fotografie_sanitize_checkbox( $new_instance['disable_image'] );
		$instance['image_alignment'] = sanitize_key( $new_instance['image_alignment'] );
		$instance['image_size']      = sanitize_key( $new_instance['image_size'] );
		$instance['disable_title']   = fotografie_sanitize_checkbox( $new_instance['disable_title'] );
		$instance['content_type']    = sanitize_key( $new_instance['content_type'] );
		$instance['content_limit']   = absint( $new_instance['content_limit'] );
		$instance['more_text']       = sanitize_text_field( $new_instance['more_text'] );
		return $instance;
	}

	function widget( $args, $instance ) {
    	$output = $args['before_widget'];

		// Set up the author bio
		if ( ! empty( $instance['title'] ) ) {
			$output .= $args['before_title'] . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $args['after_title'];
		}

		$query_args = array(
			'post_type'      => 'page',
			'posts_per_page' => -1
		);


		if ( '' != $instance['page_id'] ) {
			$page_id_array = explode( ',', $instance['page_id'] );
			$query_args['post__in'] = $page_id_array;
		}

		$loop = new WP_Query( $query_args );

		$class[] = 'article-wrap';

		$class[] = $instance['image_alignment'];

		$class[] = $instance['image_size'];

		if ( 'one-column' != $instance['layout'] ) {
			$class[] = $instance['layout'];
			$class[] = 'columns';
		}

		if ( $loop->have_posts() ) :
			$output .= '<div class="' . esc_attr( implode( ' ', $class ) ) . '">';
				while ( $loop->have_posts() ) : $loop->the_post();

					$title_attribute = the_title_attribute( 'echo=0' );


					$class = 'post-'. esc_attr( get_the_ID() ) . ' page type-page hentry';

					if( $instance['disable_image'] || !has_post_thumbnail() ) {
						$class .= " no-featured-image";
					}

					$output .= '
					<article class="' . esc_attr( $class ) . '">';

						if( !$instance['disable_image'] && has_post_thumbnail() ) {

							$output.= '
							<figure class="featured-image">
								<a href="' . esc_url( get_permalink() ) . '" title="' . $title_attribute . '">' .
									get_the_post_thumbnail(
										get_the_ID(),
										$instance['image_size']
										) .'
								</a>
							</figure>';
						}

						$output .= '<div class="entry-container">';

							if ( !$instance['disable_title'] ) {
								$output .= '<header class="entry-header"><h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" title="'. $title_attribute .'">'. get_the_title() .'</a></h2></header>';
							}

							if ( 'excerpt' == $instance['content_type'] ) {
								$output .= '<div class="entry-summary">';
								$output .= get_the_excerpt();
								$output .= '</div><!-- .entry-summary -->';
							}
							elseif ( 'content-limit' == $instance['content_type'] ) {
								$output .= '<div class="entry-summary">';
								$output .= fotografie_get_the_content_limit( (int) $instance['content_limit'], esc_html( $instance['more_text'] ) );
								$output .= '</div><!-- .entry-summary -->';
							}

							elseif( 'content' == $instance['content_type'] ) {
								$output .= '<div class="entry-content">';
								$output .= get_the_content( esc_html( $instance['more_text'] ) );
								$output .= '</div><!-- .entry-content -->';

							}

						$output .= '</div><!-- .entry-container -->';

				$output .= '</article><!-- .type-page -->';

				endwhile;
			$output .= '</div><!-- .article-wrap -->';
		endif;

		// Reset Post Data
 		wp_reset_postdata();

 		$output .= $args['after_widget'];

		echo $output;
 	}
}

/**
 * Initialize Widget
 */
function fotografie_page_widget_init() {
	register_widget( 'Fotografie_Page_Widget' );
}
add_action( 'widgets_init', 'fotografie_page_widget_init' );
